@@ -40,8 +40,23 @@ class Paths:
     NAV_BAR = '//div[@data-testid="mobile-nav-logged-in" and @class="BvyAW"]'
 
     # ENGAGEMENT PROCEDURES
-    # Like Feed Posts
-    LIKE_BTN = ''
+    # Post Interactions
+    COMMENT_TEXT_AREA = '//textarea[@class="Ypffh"]'
+    SEND_COMMENT_BTN = '//button[@="sqdOP yWX7d    y3zKF     "]'
+    LIKE_BTN = '//span[@class="fr66n"]'
+    COMMENT_BTN = '//span[@class="_15y0l"]'
+
+    # Follow User Procedure
+    FOLLOW_BTN = '//button[@class="sqdOP  L3NKy _4pI4F  y3zKF     " or @class="_5f5mN       jIbKX  _6VtSN     yZn4P   "]'
+    UNFOLLOW_BTN = '//button[@class="_5f5mN    -fzfL     _6VtSN     yZn4P   "]//descendant::span'
+    CONFIRM_UNFOLLOW_BTN = '//button[@class="aOOlW -Cab_   "]'
+    REQUESTED_BTN = '//dic[@class=" ffKix "]//descendant::button'
+    MESSAGE_USER_BTN = '//button[@class="sqdOP  L3NKy _4pI4F   _8A5w5    "]'
+    
+    # USER ACCOUNT DMs PAGE
+    DM_LIST_DIV = '//div[@class="N9abW"]//descendant::div'
+    DM_USERNAME_DIV = '//div[@class="_7UhW9   xLCgt      MMzan  KV-D4              fDxYl     "]'
+
     # GENERAL
     USE_THE_APP = '//button[@class="sqdOP yWX7d    y3zKF   cB_4K  "]' #TODO
     X = '//div[@class="storiesSpriteX__outline__44 u-__7"]'
@@ -54,25 +69,23 @@ class Paths:
     RESTRICTION_DIALOGUE_BTNS = '//div[@class="pbNvD  fPMEg    " and @role="dialog"]//descendant::button'
     BLOCK_DIV = '//div[@class="_7UhW9    vy6Bb     MMzan  KV-D4          uL8Hv     l4b0S    " and contains(text(), "unusual activity")]'
     QUERY_ELEMENT = '//body//descendant::pre'
+
     # SETTINGS OPTIONS
     LOG_OUT_BTN = '//a[@class="_34G9B H0ovd"]'
     CONFIRM_LOGOUT_BTN = '//button[@class="aOOlW  bIiDR  "]'
-    # USER ACCOUNT PROFILE PAGE
-    # Followers Procedure
+
+    # SCRAPING
+    # Scrape Followers Procedure
     FOLLOWERS_BTN = '//li[@class=" LH36I"]//descendant::a'
     FOLLOWERS_LIST_MAIN = '//main[@role="main"]'
     FOLLOWERS_LIST = '//ul[@class=" jjbaz _6xe7A"]'
     FOLLOWER_USER_DIV = '{}//li'.format(FOLLOWERS_LIST)
     FOLLOWER_COUNT = '{}//span[@class="g47SY lOXF2"]'.format(FOLLOWERS_BTN)
-    # Follow User Procedure
-    FOLLOW_BTN = '//button[@class="sqdOP  L3NKy _4pI4F  y3zKF     " or @class="_5f5mN       jIbKX  _6VtSN     yZn4P   "]'
-    UNFOLLOW_BTN = '//button[@class="_5f5mN    -fzfL     _6VtSN     yZn4P   "]//descendant::span'
-    CONFIRM_UNFOLLOW_BTN = '//button[@class="aOOlW -Cab_   "]'
-    REQUESTED_BTN = '//dic[@class=" ffKix "]//descendant::button'
-    MESSAGE_USER_BTN = '//button[@class="sqdOP  L3NKy _4pI4F   _8A5w5    "]'
-    # USER ACCOUNT DMs PAGE
-    DM_LIST_DIV = '//div[@class="N9abW"]//descendant::div'
-    DM_USERNAME_DIV = '//div[@class="_7UhW9   xLCgt      MMzan  KV-D4              fDxYl     "]'
+
+    # Scrape User Posts Procedure
+    SHORTCODE_DIV = '//div[@class="v1Nh3 kIKUG  _bz0w"]//descendant::a'
+
+    
 
 class ClientUrls:
     LOGIN_URL='https://www.instagram.com/accounts/login/'
@@ -84,6 +97,8 @@ class ClientUrls:
     LOGIN_THEN_USER = 'https://www.instagram.com/accounts/login/?next=/{}/'
     SECURITY_CODE_URL = 'https://www.instagram.com/challenge/'
     DM_URL  = 'https://www.instagram.com/direct/t/'
+    POST_URL = 'https://www.instagram.com/p/{}/'
+    COMMENTS_URL = 'https://www.instagram.com/p/{}/comments/'
 
 
 class GraphUrls:
